#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 process-extras
version:              0.7.4
visibility:           public
id:                   process-extras-0.7.4-Kzc8vKdkOsf865sYagb1vY
key:                  process-extras-0.7.4-Kzc8vKdkOsf865sYagb1vY
license:              MIT
maintainer:           David Fox <dsf@seereason.com>
author:               David Lazar, Bas van Dijk, David Fox
homepage:             https://github.com/seereason/process-extras
synopsis:             Process extras
description:
    Extends <http://hackage.haskell.org/package/process>.
    Read process input and output as ByteStrings or
    Text, or write your own ProcessOutput instance.
    Lazy process input and output.  ProcessMaker class
    for more flexibility in the process creation API.

category:             System
abi:                  491dc40310bb851f526db776e48c66a5
exposed:              True
exposed-modules:
    System.Process.ByteString System.Process.ByteString.Lazy
    System.Process.Chars System.Process.Common System.Process.ListLike
    System.Process.Run System.Process.Text System.Process.Text.Builder
    System.Process.Text.Lazy

hidden-modules:       Utils
import-dirs:          /usr/lib/ghc-9.6.6/site-local/process-extras-0.7.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/process-extras-0.7.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/process-extras-0.7.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-process-extras
hs-libraries:         HSprocess-extras-0.7.4-Kzc8vKdkOsf865sYagb1vY
depends:
    ListLike-4.7.8.4-CEOU3rXDPR9Ehuxz1MqNt3 base-4.18.2.1
    bytestring-0.11.5.3 data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    deepseq-1.4.8.1 generic-deriving-1.14.7-J0TZoWp8KsQFzSmICi7RYK
    mtl-2.3.1 process-1.6.19.0 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-process-extras/html/process-extras.haddock

haddock-html:         /usr/share/doc/haskell-process-extras/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

